@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/mga/mga_merge.c,v 1.4 2003/09/24 02:43:24 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/mga/mga_merge.c,v 1.2 2002/09/18 21:25:45 tsi Exp $ */
 
 /* All drivers should typically include these */
 #include "xf86.h"
@@ -294,7 +294,7 @@ MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
     pScrn->AdjustFrame = MGAAdjustMergeFrames;
     pScrn1->AdjustFrame = MGAAdjustMergeFrames;
     
-/*    if (!xf86SetDepthBpp(pScrn, 0, 0, 0, flags24))   FIXME:have to copy result form scrn1 
+/*    if (!xf86SetDepthBpp(pScrn, 8, 8, 8, flags24))   FIXME:have to copy result form scrn1 
   if (!xf86SetWeight(pScrn, zeros, zeros)) {
 */
 
@@ -431,17 +431,15 @@ MGAPreInitMergedFB(ScrnInfoPtr pScrn1, int flags)
 	       pMga->MinClock / 1000);
    /* Override on 2nd crtc */
 
-    if (pMga->ChipRev >= 0x80 || (pMga->Chipset == PCI_CHIP_MGAG550)) {
-	/* G450, G550 */
+    if ((pMga->ChipRev >= 0x80) || (pMga->Chipset == PCI_CHIP_MGAG550)) {	/* G450 */
         pMga->MaxClock = 234000;
     } else {
         pMga->MaxClock = 135000;
     }
-     
-     if ((ISDIGITAL2(pMga)) || (xf86ReturnOptValBool(pMga->Options, OPTION_DIGITAL2, FALSE))) {
-         pMga->MaxClock = 112000;
-     }
- 
+    
+    if ((ISDIGITAL2(pMga)) || (xf86ReturnOptValBool(pMga->Options, OPTION_DIGITAL2, FALSE))) {
+        pMga->MaxClock = 112000;
+    }
 
     xf86DrvMsg(pScrn->scrnIndex, X_DEFAULT, "CRTC2: Max pixel clock is %d MHz\n",
 	       pMga->MaxClock / 1000);
